==> tine20-allinone_2019.12.5.tar.bz2: Timetracker/js/Timetracker-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ca\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Timesheet, Timesheets"
: [
  "Full de temps"
 ,"Fulls de temps"

]
, "Account"
: "Compte"

, "Time Account (Number - Title)"
: ""

, "Billable"
: "Facturable"

, "Cleared in"
: "Comptabilitzat/Liquidat"

, "Invoice"
: ""

, "Cleared"
: "Comptabilitzat/Liquidat"

, "Date"
: "Data"

, "Start time"
: "Hora d'inici"

, "End time"
: ""

, "Duration"
: "Durada"

, "Description"
: "Descripció"

, "Type"
: ""

, "Time Account closed"
: "El compte de temps s'ha tancat"

, "hour"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Contract"
: ""

, "Title"
: "Títol"

, "Number"
: "Número"

, "Price"
: ""

, "Status"
: "Estat"

, "Billed"
: "Facturat"

, "Cleared at"
: ""

, "Booking deadline"
: "Termini"

, "Responsible"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Time Account, Time Accounts"
: [
  "Compte de temps"
 ,"Comptes de temps"

]
, "Time Account - Status"
: "Compte de temps - Estat"

, "closed"
: "tancat"

, "open"
: "obert"

, "Not a valid time"
: "No és una hora vàlida"

, "Time Account - Billed"
: ""

, "not yet billed"
: "no facturat encara"

, "to bill"
: "a facturar"

, "billed"
: "facturat"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Cleared In"
: "Comptabilitzat/Liquidat"

, "Select Time Account..."
: "Seleccioneu un compte de temps..."

, "Start"
: "Inici"

, "not set"
: "no s'ha establert"

, "End"
: ""

, "Enter description..."
: "Introduïu una descripció..."

, "Need for Clarification"
: ""

, "Failed"
: "Ha fallat"

, "Could not save {0}."
: "No s'ha pogut desar el {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "El termini d'aquest compte de temps s'ha sobrepassat."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Introdueix els propis"

, "The grant to add Timesheets to this Timeaccount"
: "Permís per a afegir fulls de temps al compte de temps"

, "View All"
: "Mostra-ho tot"

, "The grant to view Timesheets of other users"
: "Permís per a mostrar els fulls de temps a altres usuaris"

, "Book All"
: "Introdeix-los tots"

, "The grant to add Timesheets for other users"
: "Permís per a afegir fulls de temps d'altres usuaris"

, "Manage Clearing"
: "Gestiona la comptabilització/liquidació"

, "The grant to manage clearing of Timesheets"
: "Permís per a gestionar la comptabilització/liquidació dels fulls de temps"

, "without contract"
: ""

, "without responsible"
: ""

, "timeframe"
: "calendari"

, "summary"
: "resum"

, "Total Timesheets"
: "Fulls de temps en total"

, "Billable Timesheets"
: "Fulls de temps facturables"

, "Total Time"
: "Temps en total"

, "Time of Billable Timesheets"
: "Temps dels fulls de temps facturables"

, "Detail"
: "Detall"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: "Exporta com a ODS"

, "Export as CSV"
: "Exporta com a CSV"

, "Export as ..."
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Unitat"

, "Unit Price"
: "Preu unitari"

, "Budget"
: "Pressupost"

, "Timesheets are billable"
: "Els fulls de temps són facturables"

, "Access"
: "Accés"

, "Permissions"
: "Permisos"

, "Show closed"
: "Mostra els tancats"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "Timesheets ODS export configuration"
: "Configuració de l'exportació a ODS dels fulls de temps"

, "Use this configuration for the timesheet ODS export."
: "Utilitza aquesta configuració per a l'exportació a ODS del full de temps."

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "per defecte"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "Working time"
: ""

, "Project time"
: ""

, "none"
: "cap"

, "last week"
: "la setmana passada"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Manage timeaccounts"
: "Gestiona comptes de temps"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: ""

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "Timetracker"
: "Rastrejador de temps"

, "Timesheet"
: "Full de temps"

, "Timeaccount"
: ""

, "Time Account"
: "Compte de temps"

, "Delete {0}"
: ""

, "Timeaccount Grant"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Timetracker/js/Timetracker-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "calendari"

, "summary"
: "resum"

, "Total Timesheets"
: "Fulls de temps en total"

, "Billable Timesheets"
: "Fulls de temps facturables"

, "Total Time"
: "Temps en total"

, "Time of Billable Timesheets"
: "Temps dels fulls de temps facturables"

, "Description"
: "Descripció"

, "Detail"
: "Detall"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: "Exporta com a ODS"

, "Export as CSV"
: "Exporta com a CSV"

, "Export as ..."
: ""

, "Timesheet, Timesheets"
: [
  "Full de temps"
 ,"Fulls de temps"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: "Ha fallat"

, "Could not save {0}."
: "No s'ha pogut desar el {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "El termini d'aquest compte de temps s'ha sobrepassat."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: ""

, "without contract"
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Unitat"

, "Unit Price"
: "Preu unitari"

, "Factor"
: ""

, "Budget"
: "Pressupost"

, "Status"
: "Estat"

, "closed"
: "tancat"

, "open"
: "obert"

, "Cleared In"
: "Comptabilitzat/Liquidat"

, "Cleared at"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Els fulls de temps són facturables"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Compte de temps"
 ,"Comptes de temps"

]
, "Number"
: "Número"

, "Title"
: "Títol"

, "Access"
: "Accés"

, "Permissions"
: "Permisos"

, "Time Account - Billed"
: ""

, "not yet billed"
: "no facturat encara"

, "to bill"
: "a facturar"

, "billed"
: "facturat"

, "Time Account - Status"
: "Compte de temps - Estat"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Introdueix els propis"

, "The grant to add Timesheets to this Timeaccount"
: "Permís per a afegir fulls de temps al compte de temps"

, "View All"
: "Mostra-ho tot"

, "The grant to view Timesheets of other users"
: "Permís per a mostrar els fulls de temps a altres usuaris"

, "Book All"
: "Introdeix-los tots"

, "The grant to add Timesheets for other users"
: "Permís per a afegir fulls de temps d'altres usuaris"

, "Manage Clearing"
: "Gestiona la comptabilització/liquidació"

, "The grant to manage clearing of Timesheets"
: "Permís per a gestionar la comptabilització/liquidació dels fulls de temps"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Mostra els tancats"

, "Timesheets ODS export configuration"
: "Configuració de l'exportació a ODS dels fulls de temps"

, "Use this configuration for the timesheet ODS export."
: "Utilitza aquesta configuració per a l'exportació a ODS del full de temps."

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "per defecte"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "cap"

, "last week"
: "la setmana passada"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Comptabilitzat/Liquidat"

, "Billed"
: "Facturat"

, "Booking deadline"
: "Termini"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Compte"

, "Time Account (Number - Title)"
: ""

, "Billable"
: "Facturable"

, "Cleared"
: "Comptabilitzat/Liquidat"

, "Date"
: "Data"

, "Start time"
: "Hora d'inici"

, "End time"
: ""

, "Duration"
: "Durada"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "El compte de temps s'ha tancat"

, "Timetracker"
: "Rastrejador de temps"

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Manage timeaccounts"
: "Gestiona comptes de temps"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: ""

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""






, "Timesheet"
: "Full de temps"

, "Timeaccount"
: ""

, "Time Account"
: "Compte de temps"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
